@@ -5,7 +5,7 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.9
+;; Version: 1.10
 ;; Package-Requires: ((emacs "29.1") (compat "30"))
 ;; URL: https://github.com/minad/osm
 ;; Keywords: network, multimedia, hypermedia, mouse
@@ -60,7 +60,7 @@
   :prefix "osm-")
 
 (defcustom osm-curl-options
-  "--disable --fail --location --silent --max-time 30"
+  "--user-agent emacs-osm/1.0 --disable --fail --location --silent --max-time 30"
   "Curl command line options."
   :type 'string)
 
